pub struct AuditOptions {
pub ignore: Option<Vec<String>>,
pub ignore_until_fixed: Option<Vec<String>>,
}Fields
ignore: Option<Vec<String>>A list of vulnerability IDs to ignore during auditing.
Vulnerabilities matching any of the provided IDs (including aliases) will be excluded from the audit results.
ignore_until_fixed: Option<Vec<String>>A list of vulnerability IDs to ignore during auditing, but only while no fix is available.
Vulnerabilities matching any of the provided IDs (including aliases) will be excluded from the audit results as long as they have no known fix versions. Once a fix version becomes available, the vulnerability will be reported again.